@@ -5,10 +5,10 @@ This element's definition appears in https://doi.org/10.1051/m2an/197307R300331
 """
 
 from itertools import product
-from ..core.finite_element import CiarletElement
-from ..core.polynomials import polynomial_set
-from ..core.functionals import PointEvaluation
-from ..core.quadrature import get_quadrature
+from ..finite_element import CiarletElement
+from ..polynomials import polynomial_set
+from ..functionals import PointEvaluation
+from ..quadrature import get_quadrature
 
 
 class CrouzeixRaviart(CiarletElement):
