@@ -5,10 +5,10 @@ This element's definition is given in https://doi.org/10.1023/A:1004420829610
 """
 
 import sympy
-from ..core.finite_element import CiarletElement
-from ..core.polynomials import polynomial_set
-from ..core.functionals import WeightedPointEvaluation
-from ..core.symbolic import x
+from ..finite_element import CiarletElement
+from ..polynomials import polynomial_set
+from ..functionals import WeightedPointEvaluation
+from ..symbolic import x
 
 
 def kmv_tri_polyset(m, mf):
