@@ -2,7 +2,6 @@
 
 import sympy
 from itertools import product
-from ..symbolic import one, zero
 from ..finite_element import CiarletElement
 from ..moments import make_integral_moment_dofs
 from ..polynomials import quolynomial_set, Hdiv_quolynomials, Hcurl_quolynomials
@@ -48,8 +47,8 @@ class Q(CiarletElement):
             reference.tdim,
             1)
 
-    names = ["Q"]
-    references = ["interval", "quadrilateral", "hexahedron"]
+    names = ["Q", "Lagrange", "P"]
+    references = ["quadrilateral", "hexahedron"]
     min_order = 0
     continuity = "C0"
 
@@ -79,7 +78,7 @@ class DiscontinuousQ(CiarletElement):
             1)
 
     names = ["dQ"]
-    references = ["interval", "quadrilateral", "hexahedron"]
+    references = ["quadrilateral", "hexahedron"]
     min_order = 0
     continuity = "L2"
 
@@ -94,7 +93,7 @@ class VectorQ(CiarletElement):
             directions = [1]
         else:
             directions = [
-                tuple(one if i == j else zero for j in range(reference.tdim))
+                tuple(1 if i == j else 0 for j in range(reference.tdim))
                 for i in range(reference.tdim)
             ]
         for p in scalar_space.dofs:
