@@ -1,16 +1,17 @@
 import symfem
 import sympy
-from utils import all_symequal
-from symfem.symbolic import zero, x, t, subs
-from symfem.calculus import grad
+from .utils import all_symequal
+from symfem.symbolic import x, t, subs, to_sympy
+from symfem.calculus import grad, diff
 half = sympy.Rational(1, 2)
+x = [to_sympy(i) for i in x]
 
 
 def test_hct():
     e = symfem.create_element("triangle", "HCT", 3)
-    for f in e.basis:
+    for f in e.get_polynomial_basis():
         # edge from (1,0) to (1/3,1/3)
-        f1 = f.get_piece((half, zero))
+        f1 = f.get_piece((half, 0))
         f2 = f.get_piece((half, half))
         line = ((1 - 2 * t[0], t[0]))
         f1 = subs(f1, x[:2], line)
@@ -20,7 +21,7 @@ def test_hct():
 
         # edge from (0,1) to (1/3,1/3)
         f1 = f.get_piece((half, half))
-        f2 = f.get_piece((zero, half))
+        f2 = f.get_piece((0, half))
         line = ((t[0], 1 - 2 * t[0]))
         f1 = subs(f1, x[:2], line)
         f2 = subs(f2, x[:2], line)
@@ -28,8 +29,8 @@ def test_hct():
         assert all_symequal(grad(f1, 2), grad(f2, 2))
 
         # edge from (0,0) to (1/3,1/3)
-        f1 = f.get_piece((zero, half))
-        f2 = f.get_piece((half, zero))
+        f1 = f.get_piece((0, half))
+        f2 = f.get_piece((half, 0))
         line = ((t[0], t[0]))
         f1 = subs(f1, x[:2], line)
         f2 = subs(f2, x[:2], line)
@@ -39,9 +40,9 @@ def test_hct():
 
 def test_rhct():
     e = symfem.create_element("triangle", "rHCT", 3)
-    for f in e.basis:
+    for f in e.get_polynomial_basis():
         # edge from (1,0) to (1/3,1/3)
-        f1 = f.get_piece((half, zero))
+        f1 = f.get_piece((half, 0))
         f2 = f.get_piece((half, half))
         line = ((1 - 2 * t[0], t[0]))
         f1 = subs(f1, x[:2], line)
@@ -51,7 +52,7 @@ def test_rhct():
 
         # edge from (0,1) to (1/3,1/3)
         f1 = f.get_piece((half, half))
-        f2 = f.get_piece((zero, half))
+        f2 = f.get_piece((0, half))
         line = ((t[0], 1 - 2 * t[0]))
         f1 = subs(f1, x[:2], line)
         f2 = subs(f2, x[:2], line)
@@ -59,8 +60,8 @@ def test_rhct():
         assert all_symequal(grad(f1, 2), grad(f2, 2))
 
         # edge from (0,0) to (1/3,1/3)
-        f1 = f.get_piece((zero, half))
-        f2 = f.get_piece((half, zero))
+        f1 = f.get_piece((0, half))
+        f2 = f.get_piece((half, 0))
         line = ((t[0], t[0]))
         f1 = subs(f1, x[:2], line)
         f2 = subs(f2, x[:2], line)
@@ -68,10 +69,10 @@ def test_rhct():
         assert all_symequal(grad(f1, 2), grad(f2, 2))
 
         # Check that normal derivatives are linear
-        f1 = f.get_piece((half, zero)).diff(x[1]).subs(x[1], 0)
+        f1 = diff(f.get_piece((half, 0)), x[1]).subs(x[1], 0)
         f2 = f.get_piece((half, half))
-        f2 = (f2.diff(x[0]) + f2.diff(x[1])).subs(x[1], 1 - x[0])
-        f3 = f.get_piece((zero, half)).diff(x[0]).subs(x[0], 0)
-        assert f1.diff(x[0]).diff(x[0]) == 0
-        assert f2.diff(x[0]).diff(x[0]) == 0
-        assert f3.diff(x[1]).diff(x[1]) == 0
+        f2 = (diff(f2, x[0]) + diff(f2, x[1])).subs(x[1], 1 - x[0])
+        f3 = diff(f.get_piece((0, half)), x[0]).subs(x[0], 0)
+        assert diff(f1, x[0], x[0]) == 0
+        assert diff(f2, x[0], x[0]) == 0
+        assert diff(f3, x[1], x[1]) == 0
